#!/usr/bin/python

__author__ = "Ruslan Vaulin <vaulin@ligo.mit.edu>"
__version__ = "$Revision: 1.1 $"[11:-2]
__date__ = "$Date: 2012/01/21 04:15:29 $"[7:-2]

__prog__="compare_x_ray_catalogs.py"
__Id__ = "$Id: compare_x_ray_catalogs.py,v 1.1 2012/01/21 04:15:29 uid40494 Exp $"


#loading standard modules
from optparse import *
import ConfigParser
import glob
import sys
import os 
import combine_multiple_searches_utils
import numpy

import matplotlib
matplotlib.use('Agg')
import pylab
from pylal import skylocutils
from pylal import InspiralUtils
import gwem_utils
import lr_utils
import model_fit
import scipy.interpolate 
import pickle
import scipy.optimize
import scipy.special
import numpy.random
import copy 


#######################################################################################################################################
###### Main Program
########################################################################################################################################

	  
usage= """

Compare catalogs of X-ray serendipitous sources.
"""
###############################################################################
# Options
###############################################################################

def parse_command_line():

  """
  Parser function dedicated
  """
  
  # options for input data
  parser = OptionParser( usage=usage, version="version_1.0")
  
  parser.add_option("", "--swift_catalog",action="store",type="string", help=" swift catalog of serendipitous sources")
      
  parser.add_option("", "--xmm-catalog",action="store",type="string", help="2XMMi-Newton catalog")
  parser.add_option("", "--xmm-targets",action="store",type="string", help="targets of 2XMMi-Newton observations")
  parser.add_option("", "--rass-catalog",action="store",type="string", help="RASS catalog of bright sources")
                 
  parser.add_option("-P","--output-path",action="store",\
      type="string",default="",  metavar="PATH",\
      help="path where the figures would be stored")
	  
  parser.add_option("-O","--enable-output",action="store_true",\
      default="True",  metavar="OUTPUT",\
      help="enable the generation of the html and cache documents")	 
	  
  parser.add_option("-u","--user-tag",action="store",type="string",\
      default=None,metavar=" USERTAG",  \
      help="a user tag for the output filenames" )

  parser.add_option("", "--figure-resolution",action="store",type="int",\
      default=50, help="dpi of the thumbnails (50 by default)")
	  
	  
  parser.add_option("", "--html-for-cbcweb",action="store",\
      default=False, metavar = "CVS DIRECTORY", help="publish the html "\
      "output in a format that can be directly published on the cbc webpage "\
      "or in CVS. This only works IF --enable-output is also specified. The "\
      "argument should be the cvs directory where the html file will be placed "\
      "Example: --html-for-cbcweb protected/projects/s5/yourprojectdir")
  	  
  parser.add_option("","--verbose", action="store_true",\
      default=False, help="print information" )
	  
  (opts,args) = parser.parse_args()

  return opts, sys.argv[1:]
#####################################################################
opts, args = parse_command_line()
##############################################################################

# flux units erg cm^2 s-1
flux_scale = 10**(16)


# read bg fluxes from file
if opts.xmm_catalog.endswith("pickle"):
  (xmm_hgl_sources, xmm_lgl_sources) = pickle.load(open(opts.xmm_catalog, "r"))
else:
  #swift_bg_fluxes = gwem_utils.read_swift_catalog(opts.swift_catalog)*flux_scale
  xmm_hgl_sources, xmm_lgl_sources = gwem_utils.read_xmmi_catalog(opts.xmm_catalog, "/home/vaulin/analysis/GW_EM/SWIFT/data/load_2XMMi-DR3cat_v1.0.sql.txt", XMM_targets = opts.xmm_targets, RASS_catalog = opts.rass_catalog) 

  # save bg fluxes into a file

  xmm_fluxes_file = open("xmm_bg_sources.pickle", "w")
  pickle.dump((xmm_hgl_sources, xmm_lgl_sources), xmm_fluxes_file)
  xmm_fluxes_file.close()

# get fluxes
xmm_hgl_fluxes = []
for source in xmm_hgl_sources:
  xmm_hgl_fluxes.append(source[0])
xmm_hgl_fluxes = numpy.asarray(xmm_hgl_fluxes)

xmm_lgl_fluxes = []
for source in xmm_lgl_sources:
  xmm_lgl_fluxes.append(source[0])
xmm_lgl_fluxes = numpy.asarray(xmm_lgl_fluxes)




xmm_hgl_fluxes *= flux_scale
xmm_lgl_fluxes *= flux_scale

xmm_all_fluxes = numpy.concatenate((xmm_hgl_fluxes, xmm_lgl_fluxes))

if opts.verbose:
  print "  constructing histograms and estimating distributions for XMM ..."
  
 
###### HGL XMM ######################
   
# histogram
xmm_hgl_n, xmm_hgl_bin_centres = lr_utils.weighted_histogram(numpy.log10(xmm_hgl_fluxes),weight=None, norm=False, nbins=50)

xmm_hgl_bin = (xmm_hgl_bin_centres[1] - xmm_hgl_bin_centres[0])
xmm_hgl_hist_norm = numpy.sum(xmm_hgl_n)*(xmm_hgl_bin_centres[1] - xmm_hgl_bin_centres[0])


#smooth gaussian kernel pdf
xmm_hgl_step = abs(numpy.log10(numpy.max(xmm_hgl_fluxes)) - numpy.log10(numpy.min(xmm_hgl_fluxes)))/1000.0
xmm_hgl_s = numpy.arange(numpy.log10(numpy.min(xmm_hgl_fluxes)), numpy.log10(numpy.max(xmm_hgl_fluxes))+ xmm_hgl_step, xmm_hgl_step)
xmm_hgl_w = 30.0*xmm_hgl_step
xmm_hgl_pdf = [skylocutils.gaussian_kde(numpy.log10(xmm_hgl_fluxes),x,xmm_hgl_w) for x in xmm_hgl_s]

xmm_hgl_pdf= numpy.asarray(xmm_hgl_pdf)

xmm_hgl_pdf_norm = numpy.sum(xmm_hgl_pdf)*xmm_hgl_step

# Find parameters for analytical model for logN-Log(flux) curve: N(S'>S) = K/S^alpha1 + S0^alpha1, where S = log(flux).
xmm_hgl_par = model_fit.swift_onepower_fit(xmm_hgl_bin_centres, xmm_hgl_n)

xmm_hgl_power_n = model_fit.swift_onepower(xmm_hgl_par, xmm_hgl_s)
xmm_hgl_power_norm = numpy.sum(xmm_hgl_power_n)*xmm_hgl_step
 
xmm_hgl_right_cum_prob = (xmm_hgl_par[2]/xmm_hgl_power_norm)/(10**(xmm_hgl_par[0]*xmm_hgl_s[-1]) + xmm_hgl_par[1]**xmm_hgl_par[0])

print "Analytical fit paremeters for HGL catalog sources are: (alpha,S_0,K) = ",xmm_hgl_par 

###### LGL XMM #############################

# histogram
xmm_lgl_n, xmm_lgl_bin_centres = lr_utils.weighted_histogram(numpy.log10(xmm_lgl_fluxes),weight=None, norm=False, nbins=50)

xmm_lgl_bin = (xmm_lgl_bin_centres[1] - xmm_lgl_bin_centres[0])
xmm_lgl_hist_norm = numpy.sum(xmm_lgl_n)*(xmm_lgl_bin_centres[1] - xmm_lgl_bin_centres[0])


#smooth gaussian kernel pdf
xmm_lgl_step = abs(numpy.log10(numpy.max(xmm_lgl_fluxes)) - numpy.log10(numpy.min(xmm_lgl_fluxes)))/1000.0
xmm_lgl_s = numpy.arange(numpy.log10(numpy.min(xmm_lgl_fluxes)), numpy.log10(numpy.max(xmm_lgl_fluxes))+ xmm_lgl_step, xmm_lgl_step)
xmm_lgl_w = 30.0*xmm_lgl_step
xmm_lgl_pdf = [skylocutils.gaussian_kde(numpy.log10(xmm_lgl_fluxes),x,xmm_lgl_w) for x in xmm_lgl_s]

xmm_lgl_pdf= numpy.asarray(xmm_lgl_pdf)

xmm_lgl_pdf_norm = numpy.sum(xmm_lgl_pdf)*xmm_lgl_step

# Find parameters for analytical model for logN-Log(flux) curve: N(S'>S) = K/S^alpha1 + S0^alpha1, where S = log(flux).
xmm_lgl_par = model_fit.swift_onepower_fit(xmm_lgl_bin_centres, xmm_lgl_n)

xmm_lgl_power_n = model_fit.swift_onepower(xmm_lgl_par, xmm_lgl_s)
xmm_lgl_power_norm = numpy.sum(xmm_lgl_power_n)*xmm_lgl_step
 
xmm_lgl_right_cum_prob = (xmm_lgl_par[2]/xmm_lgl_power_norm)/(10**(xmm_lgl_par[0]*xmm_lgl_s[-1]) + xmm_lgl_par[1]**xmm_lgl_par[0])

print "Analytical fit paremeters for LGL catalog sources are: (alpha,S_0,K) = ",xmm_lgl_par 




######  XMM all sources #############################

# histogram
xmm_all_n, xmm_all_bin_centres = lr_utils.weighted_histogram(numpy.log10(xmm_all_fluxes),weight=None, norm=False, nbins=50)

xmm_all_bin = (xmm_all_bin_centres[1] - xmm_all_bin_centres[0])
xmm_all_hist_norm = numpy.sum(xmm_all_n)*(xmm_all_bin_centres[1] - xmm_all_bin_centres[0])


#smooth gaussian kernel pdf
xmm_all_step = abs(numpy.log10(numpy.max(xmm_all_fluxes)) - numpy.log10(numpy.min(xmm_all_fluxes)))/1000.0
xmm_all_s = numpy.arange(numpy.log10(numpy.min(xmm_all_fluxes)), numpy.log10(numpy.max(xmm_all_fluxes))+ xmm_all_step, xmm_all_step)
xmm_all_w = 30.0*xmm_all_step
xmm_all_pdf = [skylocutils.gaussian_kde(numpy.log10(xmm_all_fluxes),x,xmm_all_w) for x in xmm_all_s]

xmm_all_pdf= numpy.asarray(xmm_all_pdf)

xmm_all_pdf_norm = numpy.sum(xmm_all_pdf)*xmm_all_step

# Find parameters for analytical model for logN-Log(flux) curve: N(S'>S) = K/S^alpha1 + S0^alpha1, where S = log(flux).
xmm_all_par = model_fit.swift_onepower_fit(xmm_all_bin_centres, xmm_all_n)

xmm_all_power_n = model_fit.swift_onepower(xmm_all_par, xmm_all_s)
xmm_all_power_norm = numpy.sum(xmm_all_power_n)*xmm_all_step
 
xmm_all_right_cum_prob = (xmm_all_par[2]/xmm_all_power_norm)/(10**(xmm_all_par[0]*xmm_all_s[-1]) + xmm_all_par[1]**xmm_all_par[0])

print "Analytical fit paremeters for all catalog sources are: (alpha,S_0,K) = ",xmm_all_par 



################   PLOTS   #############################################################


# plotting

# Initializing the html output
InspiralUtils.message(opts, "Initialisation...")
opts = InspiralUtils.initialise(opts, __prog__, __version__)
fnameList = []
tagList = []
fig_num = 0
comments = ""



############# plots for XMM high galactic latitude sources ######################################

# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_hgl_s, xmm_hgl_power_n, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_hgl_bin_centres, xmm_hgl_n, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("HGL XMM number density")
pylab.legend()

name = "hgl_xmm_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("HGL XMM density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_hgl_s, numpy.cumsum(xmm_hgl_power_n[::-1])[::-1]*xmm_hgl_step/xmm_hgl_bin, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_hgl_bin_centres, numpy.cumsum(xmm_hgl_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Cumulative HGL XMM number density")
pylab.legend()

name = "hgl_xmm_cum_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Cumulative HGL XMM number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_hgl_s, xmm_hgl_pdf/xmm_hgl_pdf_norm, color='k', label="smooth pdf")
pylab.plot(xmm_hgl_s, xmm_hgl_power_n/xmm_hgl_power_norm, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_hgl_bin_centres, xmm_hgl_n/xmm_hgl_hist_norm, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Normalized HGL XMM pdf")
pylab.legend()

name = "hgl_xmm_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("HGL XMM PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_hgl_s, numpy.cumsum(xmm_hgl_pdf[::-1])[::-1]*xmm_hgl_step/xmm_hgl_pdf_norm, color='k', label="smooth pdf")
pylab.plot(xmm_hgl_s, numpy.cumsum(xmm_hgl_power_n[::-1])[::-1]*xmm_hgl_step/xmm_hgl_power_norm + xmm_hgl_right_cum_prob, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_hgl_bin_centres, numpy.cumsum(xmm_hgl_n[::-1])[::-1]*xmm_hgl_bin/xmm_hgl_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Normalized HGL XMM CDF")
pylab.legend()

name = "hgl_xmm_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Normalized HGL XMM CDF")
pylab.close()


# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_hgl_s, xmm_hgl_power_n, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_hgl_bin_centres, xmm_hgl_n, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title(" LOG HGL XMM number density")
pylab.legend()

name = "log_hgl_xmm_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG HGL XMM density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_hgl_s, numpy.cumsum(xmm_hgl_power_n[::-1])[::-1]*xmm_hgl_step/xmm_hgl_bin, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_hgl_bin_centres, numpy.cumsum(xmm_hgl_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Cumulative HGL XMM number density")
pylab.legend()

name = "log_hgl_xmm_cum_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Cumulative HGL XMM number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_hgl_s, xmm_hgl_pdf/xmm_hgl_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(xmm_hgl_s, xmm_hgl_power_n/xmm_hgl_power_norm, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_hgl_bin_centres, xmm_hgl_n/xmm_hgl_hist_norm, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Normalized HGL XMM pdf")
pylab.legend()

name = "log_hgl_xmm_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG HGL XMM PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_hgl_s, numpy.cumsum(xmm_hgl_pdf[::-1])[::-1]*xmm_hgl_step/xmm_hgl_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(xmm_hgl_s, numpy.cumsum(xmm_hgl_power_n[::-1])[::-1]*xmm_hgl_step/xmm_hgl_power_norm + xmm_hgl_right_cum_prob, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_hgl_bin_centres, numpy.cumsum(xmm_hgl_n[::-1])[::-1]*xmm_hgl_bin/xmm_hgl_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Normalized HGL XMM CDF")
pylab.legend()

name = "log_hgl_xmm_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Normalized HGL XMM CDF")
pylab.close()




############# plots for XMM low galactic latitude sources ######################################

# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_lgl_s, xmm_lgl_power_n, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_lgl_bin_centres, xmm_lgl_n, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("lgl XMM number density")
pylab.legend()

name = "lgl_xmm_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("lgl XMM density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_lgl_s, numpy.cumsum(xmm_lgl_power_n[::-1])[::-1]*xmm_lgl_step/xmm_lgl_bin, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_lgl_bin_centres, numpy.cumsum(xmm_lgl_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Cumulative lgl XMM number density")
pylab.legend()

name = "lgl_xmm_cum_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Cumulative lgl XMM number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_lgl_s, xmm_lgl_pdf/xmm_lgl_pdf_norm, color='k', label="smooth pdf")
pylab.plot(xmm_lgl_s, xmm_lgl_power_n/xmm_lgl_power_norm, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_lgl_bin_centres, xmm_lgl_n/xmm_lgl_hist_norm, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Normalized lgl XMM pdf")
pylab.legend()

name = "lgl_xmm_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("lgl XMM PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_lgl_s, numpy.cumsum(xmm_lgl_pdf[::-1])[::-1]*xmm_lgl_step/xmm_lgl_pdf_norm, color='k', label="smooth pdf")
pylab.plot(xmm_lgl_s, numpy.cumsum(xmm_lgl_power_n[::-1])[::-1]*xmm_lgl_step/xmm_lgl_power_norm + xmm_lgl_right_cum_prob, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_lgl_bin_centres, numpy.cumsum(xmm_lgl_n[::-1])[::-1]*xmm_lgl_bin/xmm_lgl_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Normalized lgl XMM CDF")
pylab.legend()

name = "lgl_xmm_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Normalized lgl XMM CDF")
pylab.close()


# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_lgl_s, xmm_lgl_power_n, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_lgl_bin_centres, xmm_lgl_n, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title(" LOG lgl XMM number density")
pylab.legend()

name = "log_lgl_xmm_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG lgl XMM density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_lgl_s, numpy.cumsum(xmm_lgl_power_n[::-1])[::-1]*xmm_lgl_step/xmm_lgl_bin, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_lgl_bin_centres, numpy.cumsum(xmm_lgl_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Cumulative lgl XMM number density")
pylab.legend()

name = "log_lgl_xmm_cum_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Cumulative lgl XMM number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_lgl_s, xmm_lgl_pdf/xmm_lgl_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(xmm_lgl_s, xmm_lgl_power_n/xmm_lgl_power_norm, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_lgl_bin_centres, xmm_lgl_n/xmm_lgl_hist_norm, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Normalized lgl XMM pdf")
pylab.legend()

name = "log_lgl_xmm_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG lgl XMM PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_lgl_s, numpy.cumsum(xmm_lgl_pdf[::-1])[::-1]*xmm_lgl_step/xmm_lgl_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(xmm_lgl_s, numpy.cumsum(xmm_lgl_power_n[::-1])[::-1]*xmm_lgl_step/xmm_lgl_power_norm + xmm_lgl_right_cum_prob, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_lgl_bin_centres, numpy.cumsum(xmm_lgl_n[::-1])[::-1]*xmm_lgl_bin/xmm_lgl_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Normalized lgl XMM CDF")
pylab.legend()

name = "log_lgl_xmm_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Normalized lgl XMM CDF")
pylab.close()


############# plots for XMM all sources ######################################

# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_all_s, xmm_all_power_n, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_all_bin_centres, xmm_all_n, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("all XMM number density")
pylab.legend()

name = "all_xmm_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("all XMM density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_all_s, numpy.cumsum(xmm_all_power_n[::-1])[::-1]*xmm_all_step/xmm_all_bin, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_all_bin_centres, numpy.cumsum(xmm_all_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Cumulative all XMM number density")
pylab.legend()

name = "all_xmm_cum_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Cumulative all XMM number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_all_s, xmm_all_pdf/xmm_all_pdf_norm, color='k', label="smooth pdf")
pylab.plot(xmm_all_s, xmm_all_power_n/xmm_all_power_norm, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_all_bin_centres, xmm_all_n/xmm_all_hist_norm, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Normalized all XMM pdf")
pylab.legend()

name = "all_xmm_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("all XMM PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_all_s, numpy.cumsum(xmm_all_pdf[::-1])[::-1]*xmm_all_step/xmm_all_pdf_norm, color='k', label="smooth pdf")
pylab.plot(xmm_all_s, numpy.cumsum(xmm_all_power_n[::-1])[::-1]*xmm_all_step/xmm_all_power_norm + xmm_all_right_cum_prob, color='b', linestyle="-", label="power fit")
pylab.plot(xmm_all_bin_centres, numpy.cumsum(xmm_all_n[::-1])[::-1]*xmm_all_bin/xmm_all_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Normalized all XMM CDF")
pylab.legend()

name = "all_xmm_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Normalized all XMM CDF")
pylab.close()


# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_all_s, xmm_all_power_n, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_all_bin_centres, xmm_all_n, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title(" LOG all XMM number density")
pylab.legend()

name = "log_all_xmm_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG all XMM density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_all_s, numpy.cumsum(xmm_all_power_n[::-1])[::-1]*xmm_all_step/xmm_all_bin, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_all_bin_centres, numpy.cumsum(xmm_all_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Cumulative all XMM number density")
pylab.legend()

name = "log_all_xmm_cum_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Cumulative all XMM number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_all_s, xmm_all_pdf/xmm_all_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(xmm_all_s, xmm_all_power_n/xmm_all_power_norm, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_all_bin_centres, xmm_all_n/xmm_all_hist_norm, "ko", label="histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Normalized all XMM pdf")
pylab.legend()

name = "log_all_xmm_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG all XMM PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_all_s, numpy.cumsum(xmm_all_pdf[::-1])[::-1]*xmm_all_step/xmm_all_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(xmm_all_s, numpy.cumsum(xmm_all_power_n[::-1])[::-1]*xmm_all_step/xmm_all_power_norm + xmm_all_right_cum_prob, color='b', linestyle="-", label="power fit")
pylab.semilogy(xmm_all_bin_centres, numpy.cumsum(xmm_all_n[::-1])[::-1]*xmm_all_bin/xmm_all_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Normalized all XMM CDF")
pylab.legend()

name = "log_all_xmm_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Normalized all XMM CDF")
pylab.close()


# PLOTS of ALL, HGL and LGL normalized distributions for XMM catalog

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_hgl_s, xmm_hgl_power_n/xmm_hgl_power_norm, color='b', linestyle="-", label="hgl")
pylab.plot(xmm_lgl_s, xmm_lgl_power_n/xmm_lgl_power_norm, color='g', linestyle="-", label="lgl")
pylab.plot(xmm_all_s, xmm_all_power_n/xmm_all_power_norm, color='r', linestyle="-", label="all")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Analytical normalized XMM pdfs")
pylab.legend()

name = "_xmm_pdfs" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("XMM PDFs")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(xmm_hgl_s, numpy.cumsum(xmm_hgl_power_n[::-1])[::-1]*xmm_hgl_step/xmm_hgl_power_norm + xmm_hgl_right_cum_prob, color='b', linestyle="-", label="hgl")
pylab.plot(xmm_lgl_s, numpy.cumsum(xmm_lgl_power_n[::-1])[::-1]*xmm_lgl_step/xmm_lgl_power_norm + xmm_lgl_right_cum_prob, color='g', linestyle="-", label="lgl")
pylab.plot(xmm_all_s, numpy.cumsum(xmm_all_power_n[::-1])[::-1]*xmm_all_step/xmm_all_power_norm + xmm_all_right_cum_prob, color='r', linestyle="-", label="all")


pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("Analytical normalized XMM CDFs")
pylab.legend()

name = "xmm_cdfs" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("XMM CDFs")
pylab.close()


#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_hgl_s, xmm_hgl_power_n/xmm_hgl_power_norm, color='b', linestyle="-", label="hgl")
pylab.semilogy(xmm_lgl_s, xmm_lgl_power_n/xmm_lgl_power_norm, color='g', linestyle="-", label="lgl")
pylab.semilogy(xmm_all_s, xmm_all_power_n/xmm_all_power_norm, color='r', linestyle="-", label="all")

pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Analytical normalized XMM pdfs")
pylab.legend()

name = "log_xmm_pdfs" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG XMM PDFs")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(xmm_hgl_s, numpy.cumsum(xmm_hgl_power_n[::-1])[::-1]*xmm_hgl_step/xmm_hgl_power_norm + xmm_hgl_right_cum_prob, color='b', linestyle="-", label="hgl")
pylab.semilogy(xmm_lgl_s, numpy.cumsum(xmm_lgl_power_n[::-1])[::-1]*xmm_lgl_step/xmm_lgl_power_norm + xmm_lgl_right_cum_prob, color='g', linestyle="-", label="lgl")
pylab.semilogy(xmm_all_s, numpy.cumsum(xmm_all_power_n[::-1])[::-1]*xmm_all_step/xmm_all_power_norm + xmm_all_right_cum_prob, color='r', linestyle="-", label="all")


pylab.xlabel(r"flux 10^-16 erg cm^-2 s-1")
pylab.title("LOG Analytical normalized XMM CDFs")
pylab.legend()

name = "log_xmm_cdfs" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG XMM CDFs")
pylab.close()




##############################################################################################################


html_filename = InspiralUtils.write_html_output(opts, args, fnameList, tagList, comment=comments)
InspiralUtils.write_cache_output(opts, html_filename, fnameList)

if opts.html_for_cbcweb:
  html_filename_publish = InspiralUtils.wrifacte_html_output(opts, args, fnameList, tagList, cbcweb=True)

##############################################################################################################



