#!/usr/bin/python

__author__ = "Ruslan Vaulin"
__version__ = "$Revision: 1.1 $"[11:-2]
__date__ = "$Date: 2012/01/21 04:15:29 $"[7:-2]

__prog__="lr_map_forcwb.py"
__Id__ = "$Id: lr_map_for_cwb_10pxls.py,v 1.1 2012/01/21 04:15:29 uid40494 Exp $"


#loading standard modules




from optparse import *
import ConfigParser
import glob
import sys
import os 
import combine_multiple_searches_utils
from pylal import skylocutils

#from pylal.sphericalutils import angle_between_points 

#import numpy as np
#np.seterr(all="raise")

from pylal.xlal.constants import *

from glue.ligolw import table
from glue.ligolw import lsctables
from glue.ligolw import ligolw
from glue.ligolw import utils
from pylal import InspiralUtils
import gwem_utils
import lr_utils
import model_fit
import scipy.interpolate 
import pickle

import numpy 
numpy.seterr(all='ignore')

import matplotlib
matplotlib.use('Agg')
import pylab

pylab.semilogy([3,4,5], [3,4,5], color='b', linestyle="-", label="exppow fit")

pylab.savefig("test.png")
pylab.close()
print "done"




def read_burst_background(file_name):
  """
  Reads cWB background triggers from a file and populates CombinedCoinc table.
  """
  bg_burst_file = open(file_name, "r")

  bg_burst_gps_times = []
  bg_burst_stats = []
  bg_burst_slides = []
  for (i, line1) in enumerate(bg_burst_file):
    if i > 28:
      line1 = line1.split(" ")
      line = []
      for el in line1:
        if (el != " ") and (el != "") :
          line.append(el)
          
      if not int(float(line[5])) == 0:
        bg_burst_slides.append( int(float(line[5])))
        bg_burst_gps_times.append(float(line[17]))
        bg_burst_stats.append(float(line[2]))
      
         
  bg_burst_file.close()

  # construct burst coincidences using combine_multiple_searches_utils.CombinedCoincTable

  slides_coincs = combine_multiple_searches_utils.CombinedCoincTable(bg_burst_gps_times, bg_burst_stats, bg_burst_slides)
  return slides_coincs


def read_burst_injections(file):
  """ 
  Reads parameters of burst injections from a txt file and populates GWEMInjections table.
  """
  inj_file = open(file, "r")
  
  injections = lsctables.New(gwem_utils.GWEMInjectionTable)
  
  for (i, line) in enumerate(inj_file):
    values = line.split(" ")
    row = gwem_utils.GWEMInjection()
    row.gps_time_s = int(values[0].split(".")[0])
    row.gps_time_ns = int(float("0."+values[0].split(".")[1])*10**(9))
    row.distance = float(values[3])
    row.hrss_fac = float(values[1])
    row.type = values[2]
    row.gw_stat = float(values[5])
    row.em_flux = 0.0
    row.ra = float(values[43])
    row.dec = float(values[44])
    row.in_top_5_swift_pxls = int(values[9])
    row.sky_map_prob = float(values[45])
    row.prob_in_top_5_swift_pxls = float(values[6])
    row.gw_lr = 0.0
    row.em_lr = 0.0
    row.joint_lr = 0.0
    row.gw_fap = 0.0
    row.em_fap = 0.0
    row.joint_fap = 0.0   
    row.event_id = i
    injections.append(row)
  return injections
  
def read_sum_skymap_background(file):
  """ 
  Reads skymap probabilities from cwb background file and sums over all pixels.
  """
  bg_file = open(file, "r")
  
  bg_gw_stats = []
  bg_sum_pms = []
  for (i, line) in enumerate(bg_file):
    values = line.split(" ")
    bg_sum_pms.append(float(values[6]))
    bg_gw_stats.append(float(values[5]))
        
  bg_file.close()      
  return bg_gw_stats, bg_sum_pms
  
  
#######################################################################################################################################
###### Main Program
########################################################################################################################################

	  
usage= """

This code maps detections statistic of cWB search into likleihood ratio,
"""
###############################################################################
# Options
###############################################################################

def parse_command_line():

  """
  Parser function dedicated
  """
  
  # options for input data
  parser = OptionParser( usage=usage, version="version_1.0")
  
  parser.add_option("", "--burst-background",action="store",type="string",\
	  metavar="CWBFILE",help="file with cWb triggers")
      
  parser.add_option("", "--injections",action="store",type="string",\
	  metavar="INJDIR",help="injection directory")
                
  parser.add_option("-P","--output-path",action="store",\
      type="string",default="",  metavar="PATH",\
      help="path where the figures would be stored")
	  
  parser.add_option("-O","--enable-output",action="store_true",\
      default="True",  metavar="OUTPUT",\
      help="enable the generation of the html and cache documents")	 
	  
  parser.add_option("-u","--user-tag",action="store",type="string",\
      default=None,metavar=" USERTAG",  \
      help="a user tag for the output filenames" )

  parser.add_option("", "--figure-resolution",action="store",type="int",\
      default=50, help="dpi of the thumbnails (50 by default)")
	  
	  
  parser.add_option("", "--html-for-cbcweb",action="store",\
      default=False, metavar = "CVS DIRECTORY", help="publish the html "\
      "output in a format that can be directly published on the cbc webpage "\
      "or in CVS. This only works IF --enable-output is also specified. The "\
      "argument should be the cvs directory where the html file will be placed "\
      "Example: --html-for-cbcweb protected/projects/s5/yourprojectdir")
  	  
  parser.add_option("","--verbose", action="store_true",\
      default=False, help="print information" )
	  
  (opts,args) = parser.parse_args()

  return opts, sys.argv[1:]
#####################################################################
opts, args = parse_command_line()
##############################################################################


# read burst background triggers
#bg_triggers = read_burst_background(opts.burst_background)


# get statistic
#bg_stats = bg_triggers.getstat()

bg_stats, bg_sum_pms = read_sum_skymap_background(opts.burst_background)

bg_stats = numpy.asarray(bg_stats)

# histogram
bg_n, bg_bin_centres = lr_utils.weighted_histogram(bg_stats,weight=None, norm=False, nbins=20)

bg_bin = (bg_bin_centres[1] - bg_bin_centres[0])
bg_hist_norm = numpy.sum(bg_n)*(bg_bin_centres[1] - bg_bin_centres[0])

#smooth gaussian kernel pdf
bg_step = (bg_bin_centres[1] - bg_bin_centres[0])/10.0
bg_x = numpy.arange(bg_stats.min(), bg_stats.max()+ bg_step, bg_step)
bg_w = 0.5*(bg_bin_centres[1] - bg_bin_centres[0])
bg_pdf = [skylocutils.gaussian_kde(bg_stats,x,bg_w) for x in bg_x]

bg_pdf= numpy.asarray(bg_pdf)

bg_pdf_norm = numpy.sum(bg_pdf)*bg_step

#model fits
bg_exppowparfit, bg_exppowpar, bg_exppow = model_fit.exppowfit(bg_bin_centres, bg_n, hybridn=20)

bg_powpowparfit, bg_powpowpar, bg_powpow = model_fit.powpowfit(bg_bin_centres, bg_n, hybridn=20)

bg_exppow_n = bg_exppow(bg_exppowpar, bg_x)
bg_exppow_norm = numpy.sum(bg_exppow_n)*bg_step

bg_powpow_n = bg_powpow(bg_powpowpar, bg_x)
bg_powpow_norm = numpy.sum(bg_powpow_n)*bg_step



#read injections

if opts.injections.endswith(".xml"): 

  realistic_injections = gwem_utils.read_gwem_injections(opts.injections)

else:

  injections = read_burst_injections(opts.injections)

  rho_horizon = 3.5 

  # get rid of extra loud injections
  inj_types = injections.get_column("type")
  unique_inj_types = numpy.unique(inj_types)

  inj_hrss_fac = injections.get_column("hrss_fac")
  unique_hrss_fac = numpy.unique(inj_hrss_fac)




  realistic_injections = lsctables.New(gwem_utils.GWEMInjectionTable)
  for type in unique_inj_types:
    for hrss_fac in unique_hrss_fac:
      sub_class_inj = injections.get_subclass(type, hrss_fac)
      if len(sub_class_inj) > 0:
        too_loud = 0
        for row in sub_class_inj:
          if row.gw_stat*row.distance/50.0 > rho_horizon:
            too_loud = 1
        if too_loud == 0:
          realistic_injections.extend(sub_class_inj)
            

  # save realistic injections into file
  output_realistic_inj_file =  open("realistic_injections_" + str(rho_horizon)+".xml", "w")
	
  # create xml doc
  output_doc = ligolw.Document()
	
  #create LIGO_LW element
  output_ligo_lw = ligolw.LIGO_LW()
	
  #append it to xml doc
  output_doc.appendChild(output_ligo_lw)

  #adding GWEMInjections table
  output_doc.childNodes[0].appendChild(realistic_injections)
	
	  
  #writing xml doc to the output file
  output_doc.write(output_realistic_inj_file)
  output_realistic_inj_file.close()



# get gw stats
realistic_inj_stats = realistic_injections.get_column("gw_stat")



# histogram
inj_n, inj_bin_centres = lr_utils.weighted_histogram(numpy.log10(realistic_inj_stats),weight=None, norm=False, nbins=50)

inj_bin = (inj_bin_centres[1] - inj_bin_centres[0])
inj_hist_norm = numpy.sum(inj_n)*(inj_bin_centres[1] - inj_bin_centres[0])


#smooth gaussian kernel pdf
inj_step = abs(numpy.log10(numpy.max(realistic_inj_stats)) - numpy.log10(numpy.min(realistic_inj_stats)))/1000.0
inj_x = numpy.arange(numpy.log10(numpy.min(realistic_inj_stats)), numpy.log10(numpy.max(realistic_inj_stats))+ inj_step, inj_step)
inj_w = 30.0*inj_step
inj_pdf = [skylocutils.gaussian_kde(numpy.log10(realistic_inj_stats),x,inj_w) for x in inj_x]

inj_pdf= numpy.asarray(inj_pdf)

inj_pdf_norm = numpy.sum(inj_pdf)*inj_step


# model fit
inj_par = model_fit.shiftedpowfit(inj_bin_centres, inj_n)

inj_shiftedpow_n = model_fit.shiftedpow(inj_par, inj_x)
inj_shiftedpow_norm = numpy.sum(inj_shiftedpow_n)*inj_step


# define interpolationt curve for injections which will be used to calculate likelihood ratio
inj_curve = scipy.interpolate.interp1d(inj_x, inj_pdf/inj_pdf_norm, kind="linear")



# Likelihood ratio calculation

#LR_scale = 10**(5)
LR_scale =  numpy.exp(1)/ gwem_utils.calculate_cwb_lr(numpy.min(bg_stats), bg_exppowpar, inj_curve)

# calculate lr for background
bg_lr = []

for stat in bg_stats:
  bg_lr.append(gwem_utils.calculate_cwb_lr(stat, bg_exppowpar, inj_curve))


bg_lr = LR_scale * numpy.asarray(bg_lr)

# calculate lr for injections

inj_lr = []

for stat in realistic_inj_stats:
  inj_lr.append(gwem_utils.calculate_cwb_lr(stat, bg_exppowpar, inj_curve))
  
inj_lr = LR_scale * numpy.asarray(inj_lr)

# save key elements of likelihood ratio calculation into a file

lr_file = open("lr_params.pickle", "w")
pickle.dump((inj_x, inj_pdf/inj_pdf_norm), lr_file)
pickle.dump(bg_exppowpar, lr_file)
pickle.dump(LR_scale, lr_file)
lr_file.close()


# save bg and inj likelihood ratios in file

bg_file = open("bg_lr.pickle", "w")
pickle.dump((bg_stats, numpy.asarray(bg_lr)), bg_file)
bg_file.close()

inj_file = open("inj_lr.pickle", "w")
pickle.dump((realistic_inj_stats, numpy.asarray(inj_lr)), inj_file)
inj_file.close()  


# do fit for background lr 

# histogram
bg_lr_n, bg_lr_bin_centres = lr_utils.weighted_histogram(numpy.log(bg_lr),weight=None, norm=False, nbins=20)

bg_lr_bin = (bg_lr_bin_centres[1] - bg_lr_bin_centres[0])
bg_lr_hist_norm = numpy.sum(bg_lr_n)*(bg_lr_bin_centres[1] - bg_lr_bin_centres[0])

#smooth Gaussian kernel pdf
bg_lr_step = (bg_lr_bin_centres[1] - bg_lr_bin_centres[0])/10.0
bg_lr_x = numpy.arange(numpy.log(bg_lr.min()), numpy.log(bg_lr.max())+ bg_lr_step, bg_lr_step)
bg_lr_w = 0.5*(bg_lr_bin_centres[1] - bg_lr_bin_centres[0])
bg_lr_pdf = [skylocutils.gaussian_kde(numpy.log(bg_lr),x,bg_lr_w) for x in bg_lr_x]

bg_lr_pdf= numpy.asarray(bg_lr_pdf)

bg_lr_pdf_norm = numpy.sum(bg_lr_pdf)*bg_lr_step

#model fits
bg_lr_exppowparfit, bg_lr_exppowpar, bg_lr_exppow = model_fit.exppowfit(bg_lr_bin_centres, bg_lr_n, hybridn=20)

#bg_lr_powpowparfit, bg_lr_powpowpar, bg_lr_powpow = model_fit.powpowfit(bg_lr_bin_centres, bg_lr_n, hybridn=20)

bg_lr_exppow_n = bg_lr_exppow(bg_lr_exppowpar, bg_lr_x)
bg_lr_exppow_norm = numpy.sum(bg_lr_exppow_n)*bg_lr_step

#bg_lr_powpow_n = bg_lr_powpow(bg_lr_powpowpar, bg_lr_x)
#bg_lr_powpow_norm = numpy.sum(bg_lr_powpow_n)*bg_lr_step


#exponential fit

bg_lr_par = model_fit.expfit(bg_lr_bin_centres, bg_lr_n)

bg_lr_exp_n = model_fit.exponential(bg_lr_par, bg_lr_x)
bg_lr_exp_norm = numpy.sum(bg_lr_exp_n)*bg_lr_step

#analytical normalization factor
bg_lr_exp_theor_norm = numpy.exp(bg_lr_par[0] - bg_lr_par[1]*numpy.log(bg_lr.min()))/bg_lr_par[1]



print "Background pdf of cwb likelihood ratio is approximated by exp(a - b*ln(\Lambda))/N"
print "a = ", bg_lr_par[0]
print "b = ", bg_lr_par[1]
print "N = ", bg_lr_exp_theor_norm


fap_file = open("cwb_fap_params.pickle", "w")
pickle.dump([bg_lr_par[0], bg_lr_par[1], bg_lr_exp_theor_norm] , fap_file)
fap_file.close()


############################### PLOTS ########################################################
# plotting


# Initializing the html output
InspiralUtils.message(opts, "Initialisation...")
opts = InspiralUtils.initialise(opts, __prog__, __version__)
fnameList = []
tagList = []
fig_num = 0
comments = ""


# plot of number denisty for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []

pylab.plot(bg_x, bg_exppow_n, color='b', linestyle="-", label="exppow fit")
pylab.plot(bg_x, bg_powpow_n, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_bin_centres, bg_n, "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title("Background number density")
pylab.legend()

name = "background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Background number density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []

pylab.plot(bg_x, numpy.cumsum(bg_exppow_n[::-1])[::-1]*bg_step/bg_bin, color='b', linestyle="-", label="exppow fit")
pylab.plot(bg_x, numpy.cumsum(bg_powpow_n[::-1])[::-1]*bg_step/bg_bin, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_bin_centres, numpy.cumsum(bg_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title("Cumulative background number density")
pylab.legend()

name = "cum_background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Cumulative background number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(bg_x, bg_pdf/bg_pdf_norm, color='k', label="smooth pdf")
pylab.plot(bg_x, bg_exppow_n/bg_exppow_norm, color='b', linestyle="-", label="exppow fit")
pylab.plot(bg_x, bg_powpow_n/bg_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_bin_centres, bg_n/bg_hist_norm, "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title("Normalized background pdf")
pylab.legend()

name = "background_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Background PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(bg_x, numpy.cumsum(bg_pdf[::-1])[::-1]*bg_step/bg_bin/bg_pdf_norm, color='k', label="smooth pdf")
pylab.plot(bg_x, numpy.cumsum(bg_exppow_n[::-1])[::-1]*bg_step/bg_bin/bg_exppow_norm, color='b', linestyle="-", label="exppow fit")
pylab.plot(bg_x, numpy.cumsum(bg_powpow_n[::-1])[::-1]*bg_step/bg_bin/bg_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_bin_centres, numpy.cumsum(bg_n[::-1])[::-1]/bg_hist_norm, "ko", label="bg histogram")

pylab.xlabel(r"\rho")
pylab.title("Normalized background CDF")
pylab.legend()

name = "background_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Background CDF")
pylab.close()



#log plots ###################################

# plot of number denisty and pdf for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []

pylab.semilogy(bg_x, bg_exppow_n, color='b', linestyle="-", label="exppow fit")
pylab.semilogy(bg_x, bg_powpow_n, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_bin_centres, bg_n+10**(-8), "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title(" LOG Background number density")
pylab.legend()

name = "log_background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Background number density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
#pylab.plot(bg_x, numpy.cumsum(bg_pdf[::-1])[::-1]*bg_step/bg_bin, color='k', label="smooth bg")
pylab.semilogy(bg_x, numpy.cumsum(bg_exppow_n[::-1])[::-1]*bg_step/bg_bin, color='b', linestyle="-", label="exppow fit")
pylab.semilogy(bg_x, numpy.cumsum(bg_powpow_n[::-1])[::-1]*bg_step/bg_bin, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_bin_centres, numpy.cumsum(bg_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title("LOG Cumulative background number density")
pylab.legend()

name = "log_cum_background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Cumulative background number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(bg_x, bg_pdf/bg_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(bg_x, bg_exppow_n/bg_exppow_norm, color='b', linestyle="-", label="exppow fit")
pylab.semilogy(bg_x, bg_powpow_n/bg_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_bin_centres, bg_n/bg_hist_norm, "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title("LOG Normalized background pdf")
pylab.legend()

name = "log_background_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Background PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(bg_x, numpy.cumsum(bg_pdf[::-1])[::-1]*bg_step/bg_bin/bg_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(bg_x, numpy.cumsum(bg_exppow_n[::-1])[::-1]*bg_step/bg_bin/bg_exppow_norm, color='b', linestyle="-", label="exppow fit")
pylab.semilogy(bg_x, numpy.cumsum(bg_powpow_n[::-1])[::-1]*bg_step/bg_bin/bg_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_bin_centres, numpy.cumsum(bg_n[::-1])[::-1]/bg_hist_norm, "ko", label="histogram")

pylab.xlabel(r"\rho")
pylab.title("LOG Normalized background cdf")
pylab.legend()

name = "log_background_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Background CDF")
pylab.close()


####################plots for  injections #################################

# plot of normilized  number denisty for injections

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(inj_x, inj_pdf/inj_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(inj_x, inj_shiftedpow_n/inj_shiftedpow_norm, color='r', label="power fit")
pylab.semilogy(inj_bin_centres, inj_n/inj_hist_norm, "ro", label="histogram")
pylab.xlabel(r"$log_{10}\rho$")
pylab.title("Normalized Injections pdf")
pylab.legend()

name = "injections_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Injections pdf")
pylab.close()



#fig_num += 1
#pylab.figure(fig_num)
#legend_text = []
#pylab.loglog(inj_x, inj_pdf/inj_pdf_norm, color='r', label="injections pdf")
#pylab.loglog(numpy.sort(inj_stats)[::-1], numpy.arange(1, len(inj_stats) + 1), "ro")
#pylab.loglog(numpy.sort(inj_stats)[::-1], numpy.min(inj_stats)**3*len(inj_stats)*numpy.sort(inj_stats)[::-1]**(-3))
#pylab.xlabel(r"$\rho$")
#pylab.ylabel("N")
#pylab.title("Cumulative distribution of injections")

#name = "injections_cdf" 
#fname = InspiralUtils.set_figure_name(opts, name)
#fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
#fnameList.append(fname)
#tagList.append("Injections cdf")
#pylab.close()


#### cumulative distibution for realistic injections
fig_num += 1
pylab.figure(fig_num)
legend_text = []
#pylab.loglog(inj_x, inj_pdf/inj_pdf_norm, color='r', label="injections pdf")
pylab.semilogy(numpy.sort(numpy.log10(realistic_inj_stats))[::-1], numpy.arange(1, len(realistic_inj_stats) + 1)/float(len(realistic_inj_stats)), "ro", label="data")
pylab.semilogy(inj_x, numpy.cumsum(inj_pdf[::-1])[::-1]*inj_step/inj_pdf_norm, color='k', label="smooth pdf")
pylab.semilogy(inj_x, numpy.cumsum(inj_shiftedpow_n[::-1])[::-1]*inj_step/inj_shiftedpow_norm, color='b', linestyle="-", label="power fit")
pylab.plot(inj_bin_centres, numpy.cumsum(inj_n[::-1])[::-1]*inj_bin/inj_hist_norm, "k^", label="histogram")
pylab.xlabel(r"$log_{10}\rho$")
#pylab.ylabel("")
pylab.title("Normalized injections cdf")

name = "realistic_injections_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Normalized injections cdf")
pylab.close()



########### LR plot  ###############

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.loglog(realistic_inj_stats, inj_lr, 'rx', label="injections")
pylab.loglog(bg_stats, bg_lr, 'k+', label="background")
pylab.xlabel(r"$\rho$")
pylab.ylabel("Likelihood ratio")
pylab.title("Likelihood ratio")
pylab.legend()

name = "log_lr" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Likelihood ratio")
pylab.close()


fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(realistic_inj_stats, inj_lr, 'rx', label="injections")
pylab.semilogy(bg_stats, bg_lr, 'k+', label="background")
pylab.xlabel(r"$\rho$")
pylab.xlim(xmax = 10.0)
pylab.ylim(ymax = 10**8)
pylab.ylabel("Likelihhod ratio")
pylab.title("Likelihood ratio vs cwb statistic")
pylab.legend()

name = "lr" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Likelihood ratio")
pylab.close()


#### cumulative background distibution for lr 
fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.loglog(numpy.sort(bg_lr)[::-1], numpy.arange(1, len(bg_lr) + 1)/float(len(bg_lr)), "k+", label="data")
pylab.xlabel(r"likelihood ratio")
#pylab.ylabel("")
pylab.title("Cumulative distribution for background")
pylab.legend()

name = "bg_cum_num" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Cumulative distribution for background")
pylab.close()


####### PLOTS of fitting LR for Background ############

# plot of LR number denisty and pdf for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(bg_lr_x, bg_lr_exppow_n, color='b', linestyle="-", label="exppow fit")
#pylab.plot(bg_lr_x, bg_lr_powpow_n, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_lr_x, bg_lr_exp_n, color='g', linestyle="-", label="exp fit")
pylab.plot(bg_lr_bin_centres, bg_lr_n, "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("LR Background number density")
pylab.legend()

name = "background_lr_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Background number density")
pylab.close()

# plot of LR cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_exppow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin, color='b', linestyle="-", label="exppow fit")
#pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_powpow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_exp_n[::-1])[::-1]*bg_lr_step/bg_lr_bin, color='g', linestyle="-", label="exp fit")
pylab.plot(bg_lr_bin_centres, numpy.cumsum(bg_lr_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("Cumulative LR background number density")
pylab.legend()

name = "cum_lr_background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("Cumulative LR background number density")
pylab.close()

#normalized distributions PDF

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(bg_lr_x, bg_lr_pdf/bg_lr_pdf_norm, color='k', label="smooth")
pylab.plot(bg_lr_x, bg_lr_exppow_n/bg_lr_exppow_norm, color='b', linestyle="-", label="exppow fit")
#pylab.plot(bg_lr_x, bg_lr_powpow_n/bg_lr_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_lr_x, bg_lr_exp_n/bg_lr_exp_theor_norm, color='g', linestyle="-", label="exp fit")
pylab.plot(bg_lr_bin_centres, bg_lr_n/bg_lr_hist_norm, "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("Normalized LR background pdf")
pylab.legend()

name = "lr_background_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LR background PDF")
pylab.close()

# CDF

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_pdf[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_pdf_norm, color='k', label="smooth")
pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_exppow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_exppow_norm, color='b', linestyle="-", label="exppow fit")
#pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_powpow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.plot(bg_lr_x, numpy.cumsum(bg_lr_exp_n[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_exp_theor_norm, color='g', linestyle="-", label="exp fit")
pylab.plot(bg_lr_bin_centres, numpy.cumsum(bg_lr_n[::-1])[::-1]/bg_lr_hist_norm, "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("Normalized LR background CDF")
pylab.legend()

name = "lr_background_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LR background CDF")
pylab.close()



#log plots ###################################

# plot of number denisty and pdf for background

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(bg_lr_x, bg_lr_exppow_n, color='b', linestyle="-", label="exppow fit")
#pylab.semilogy(bg_lr_x, bg_lr_powpow_n, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_lr_x, bg_lr_exp_n, color='g', linestyle="-", label="exp fit")
pylab.semilogy(bg_lr_bin_centres, bg_lr_n, "ko", label="bg histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title(" LOG LR background number density")
pylab.legend()

name = "log_lr_background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG LR background number density")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_exppow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin, color='b', linestyle="-", label="exppow fit")
#pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_powpow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_exp_n[::-1])[::-1]*bg_lr_step/bg_lr_bin, color='g', linestyle="-", label="exp fit")
pylab.semilogy(bg_lr_bin_centres, numpy.cumsum(bg_lr_n[::-1])[::-1], "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("LOG LR cumulative background number density")
pylab.legend()

name = "log_lr_cum_background_density" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG LR Cumulative background number density")
pylab.close()

#normalized distributions

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(bg_lr_x, bg_lr_pdf/bg_lr_pdf_norm, color='k', label="smooth")
pylab.semilogy(bg_lr_x, bg_lr_exppow_n/bg_lr_exppow_norm, color='b', linestyle="-", label="exppow fit")
#pylab.semilogy(bg_lr_x, bg_lr_powpow_n/bg_lr_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_lr_x, bg_lr_exp_n/bg_lr_exp_theor_norm, color='g', linestyle="-", label="exp fit")
pylab.semilogy(bg_lr_bin_centres, bg_lr_n/bg_lr_hist_norm, "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("LOG Normalized LR background pdf")
pylab.legend()

name = "log_lr_background_pdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG Normalized LR background PDF")
pylab.close()

# plot of cumulative number densities

fig_num += 1
pylab.figure(fig_num)
legend_text = []
pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_pdf[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_pdf_norm, color='k', label="smooth")
pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_exppow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_exppow_norm, color='b', linestyle="-", label="exppow fit")
#pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_powpow_n[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_powpow_norm, color='r', linestyle="--", label="powpow fit")
pylab.semilogy(bg_lr_x, numpy.cumsum(bg_lr_exp_n[::-1])[::-1]*bg_lr_step/bg_lr_bin/bg_lr_exp_theor_norm, color='g', linestyle="-", label="exp fit")
pylab.semilogy(bg_lr_bin_centres, numpy.cumsum(bg_lr_n[::-1])[::-1]/bg_lr_hist_norm, "ko", label="histogram")

pylab.xlabel("logarithm of likelihood ratio")
pylab.title("LOG Normalized LR background CDF")
pylab.legend()

name = "log_lr_background_cdf" 
fname = InspiralUtils.set_figure_name(opts, name)
fname_thumb = InspiralUtils.savefig_pylal(filename=fname, doThumb=True, dpi_thumb=opts.figure_resolution)
fnameList.append(fname)
tagList.append("LOG LR background CDF")
pylab.close()







##############################################################################################################


html_filename = InspiralUtils.write_html_output(opts, args, fnameList, tagList, comment=comments)
InspiralUtils.write_cache_output(opts, html_filename, fnameList)

if opts.html_for_cbcweb:
  html_filename_publish = InspiralUtils.wrifacte_html_output(opts, args, fnameList, tagList, cbcweb=True)

##############################################################################################################










