from glue.ligolw import ligolw
from glue.ligolw import table
from glue.ligolw import lsctables
from glue.ligolw import utils
from glue.ligolw import ilwd
from glue.ligolw import types
from glue import segments
from glue import iterutils
from pylal import rate
import numpy



def get_cum_prob_from_freq(freq_array):

  p1 = numpy.fliplr(freq_array)
  p1[1] = p1[1].cumsum() / numpy.sum(p1[1])
  p = numpy.fliplr(p1)
  return p

def get_cum_rate_from_freq(freq_array, time):

  p1 = numpy.fliplr(freq_array)
  p1[1] = p1[1].cumsum()/time
  p = numpy.fliplr(p1)
  return p




def get_freq_array(snr, weight):

  sorted_indexes = numpy.argsort(snr)
  
  freq_array = numpy.zeros((2, len(snr)))
  for i in range(len(snr)):
	freq_array[0][i] = snr[sorted_indexes[i]]
	if weight==None:
	  freq_array[1][i] = 1.0 
	else:
	  freq_array[1][i] = weight[sorted_indexes[i]]
  return freq_array
  


def weighted_histogram(array,weight=None, norm=False, nbins=10, set_max=None, set_min=None):
  """
  Weighted histogram function; It returns 
  y is a numpy array containing number of events in the corresponding bin;
  if norm=True then y is normalized to unity.
  x is a numpy array containing bins (namely center of each bin).
  @param array: numpy array containing the quatities for which the histogram will be generated.
  @param bins: integer that sets the number of bins in the histogram.
  @param weight: if given must be array of weights for each element of array to be binned.
  @param norm: if True then the histogram is normed to 1, otherwise nopthing is done.
  @param set_max: parameter that sets the maximum value for bins, if not given it is determined from the data.
  @param set_min: parameter that sets the minimum value for bins, if not given it is determined from the data.
  """

  if weight==None:
    weight = numpy.ones(len(array))
  if not set_max:
    max_element = numpy.max(array)
  else:
    max_element = set_max
  if not set_min:
    min_element = numpy.min(array)
  else:
    min_element = set_min
  bins_object = rate.LinearBins(min_element, max_element + 10**(-7), nbins)
  y = numpy.zeros(nbins)
  for i in range(len(array)):
    if (array[i] >= min_element) and (array[i] <= max_element):
      bin_index = bins_object[array[i]]
      y[bin_index] += weight[i]
  if norm:
    normalization = numpy.sum(y)
    y = y/normalization
  x = bins_object.centres()
  return y, x
