#!/usr/bin/python


__author__ = "Ruslan Vaulin <vaulin@gravity.phys.uwm.edu>"
__version__ = "$Revision: 1.1 $"[11:-2]
__date__ = "$Date: 2012/01/21 04:15:29 $"[7:-2]
__name__="plot_roc_curves"
__prog__="plot_roc_curves.py"
__Id__ = "$Id: plot_roc_curves.py,v 1.1 2012/01/21 04:15:29 uid40494 Exp $"

#loading standard modules
from optparse import *
import ConfigParser
import glob
import sys
import os 
import pickle



import numpy

import matplotlib
matplotlib.use('Agg')
import pylab

import scipy.interpolate 
import pickle
import matplotlib.cm as cm
#######################################################################################################################################
###### Main Program
########################################################################################################################################

	  
usage= """
usage: %prog [options]


"""
###############################################################################
# Options
###############################################################################

def parse_command_line():

  """
  Parser function dedicated
  """
  
  # options for input data
  parser = OptionParser( usage=usage, version="%prog CVS $Id: plot_roc_curves.py,v 1.1 2012/01/21 04:15:29 uid40494 Exp $ " )
  
  parser.add_option("","--roc-glob", action="store", type="string", default=False,  metavar="", help="glob for roc pickle files")	
   
  parser.add_option("","--roc-glob-10pxls", action="store", type="string", default=False,  metavar="", help="glob for roc pickle files for 10 pxls runs")
    
  parser.add_option("","--normalization", action="store", type="string", default="original",  metavar="", help="normalization factor for efficiency in ROC curves")        
 	  
  (opts,args) = parser.parse_args()

  return opts, sys.argv[1:]
#####################################################################
opts, args = parse_command_line()
##############################################################################

######## zerolag, slides duration, in seconds ########################
T_slides = 255345643.0
T_0 = 1437592.0
N_b = 342.0
N_ave = N_b * T_0 / T_slides

FAP0 = 1.0 - numpy.exp(-N_ave)  

##### Normalization of efficiency ###########
# numbers below are extracted from file
#original Efficiency was normalized by the total number of injections that produced a trigger with rho > 3.5 (this is a standard threshold)
N_inj_3_5 = 1171.0 
# number of injections that produced a trigger with rho > 3.0 (minimum rho for injections that made it into injection file)
N_inj_3_0 = 1532.0


if opts.normalization == "original":
  N_factor = 1.0
elif opts.normalization == "3.0":
  N_factor = N_inj_3_5 / N_inj_3_0
  


roc_files = glob.glob(opts.roc_glob)

faps_effs = []
elabels = []
for file in roc_files:
  roc_file = open(file, "r")
  (all_gw_fap,all_gw_eff) = pickle.load(roc_file)
  (localized_joint_fap,localized_joint_eff) = pickle.load(roc_file)
  (all_joint_fap,all_joint_eff) = pickle.load(roc_file)
  (hybrid_joint_fap,hybrid_joint_eff) = pickle.load(roc_file)
  
  faps_effs.append((file.split("_e")[-1].split(".")[0],hybrid_joint_fap,hybrid_joint_eff))
  
  elabels.append("e" + file.split("_e")[-1].split(".")[0])
  
  
faps_effs.sort()
  
  
if opts.roc_glob_10pxls:

  roc_files_10pxls = glob.glob(opts.roc_glob_10pxls)

  faps_effs_10pxls = []
  elabels_10pxls = []
  for file in roc_files_10pxls:
    roc_file_10pxls = open(file, "r")
    (all_gw_fap_10pxls,all_gw_eff_10pxls) = pickle.load(roc_file_10pxls)
    (localized_joint_fap_10pxls,localized_joint_eff_10pxls) = pickle.load(roc_file_10pxls)
    (all_joint_fap_10pxls,all_joint_eff_10pxls) = pickle.load(roc_file_10pxls)
    (hybrid_joint_fap_10pxls,hybrid_joint_eff_10pxls) = pickle.load(roc_file_10pxls)
    
    faps_effs_10pxls.append(("10p e" + file.split("_e")[-1].split(".")[0],hybrid_joint_fap_10pxls,hybrid_joint_eff_10pxls))
    
    elabels_10pxls.append("10p e" + file.split("_e")[-1].split(".")[0])
    
    
  faps_effs_10pxls.sort()


    
  
pylab.rcParams.update(
 {'axes.labelsize': 18,
  'text.fontsize': 18,
  'legend.fontsize': 17,
  'xtick.labelsize': 14,
  'ytick.labelsize': 14,
  'text.usetex': True,
  'font.family': 'serif',
  'font.serif': ['times'],
  'savefig.dpi': 600
  })
  
 
label_dic = {}
label_dic["-14"] = r"$10^{-14}$"  
label_dic["-13"] = r"$10^{-13}$"
label_dic["-12"] = r"$10^{-12}$"
label_dic["-11"] = r"$10^{-11}$"
label_dic["-10"] = r"$10^{-10}$"
label_dic["-09"] = r"$10^{-9}$"
label_dic["-08"] = r"$10^{-8}$"   
     
# plot for BNS  

fig = pylab.figure(figsize=(7,7))
axis_pos = (0.17, 0.14, 0.8, 0.8)
ax = fig.add_axes(axis_pos)
 
legend_text = []
markers = ["o","s", "d", "^", "v", "p", "h"]
colors = ["g", "b", "y", "m", "r", "c", "orange"]

pylab.loglog(FAP0*all_gw_fap, N_factor*all_gw_eff, color='k', linestyle="--", linewidth=2, marker ="x", markersize=0.0, label="gw data only")
for i in range(len(elabels)):
  pylab.loglog(FAP0*faps_effs[i][1], N_factor*faps_effs[i][2], color=colors[i], linestyle="-", linewidth=2, marker=markers[i], markersize=0.0, label=("gw-em "+ label_dic[faps_effs[i][0]]))

if opts.roc_glob_10pxls:
  pylab.hold(True)
  for i in range(len(elabels_10pxls)):
    pylab.loglog(FAP0*faps_effs_10pxls[i][1], N_factor*faps_effs_10pxls[i][2], color=colors[i], linestyle=":", linewidth=2, marker=markers[i], markersize=0.0)



#pylab.axvline(1.0 - scipy.special.erf(1.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(2.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(3.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(4.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(5.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(6.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(7.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(8.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(9.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(10.0/2.0**0.5), color="gray", linestyle="--")

sigmas = []
xticks_labels = []
for i in range(8,0,-1):
  sigmas.append(1.0 - scipy.special.erf(float(i)/2.0**0.5))
  xticks_labels.append(str(i)+r"$\sigma$")
pylab.xticks(sigmas, xticks_labels)
pylab.xlim(xmin=(1.0 - scipy.special.erf(8.0/2.0**0.5)))
pylab.ylim(ymin=2*10.0**-2)
pylab.grid()

#pylab.axvline(2.0*(1.0 - scipy.special.erf(5.0/2.0**0.5)), color="k", linewidth=2)
#pylab.axhline(0.2, color="k", linewidth=2)

pylab.xlabel(r"False Alarm Probability")
pylab.ylabel(r"Efficiency")
pylab.title("ROC curves for CWB and CWB+Swift searches")
#pylab.legend(loc=2)
pylab.legend(loc=2)

pylab.savefig("cwb_swift_roc.png")
pylab.savefig("cwb_swift_roc.pdf")
pylab.savefig("cwb_swift_roc.eps")

pylab.close()


fig = pylab.figure(figsize=(7,7))
axis_pos = (0.17, 0.14, 0.8, 0.8)
ax = fig.add_axes(axis_pos)
 
legend_text = []
markers = ["o","s", "d", "^", "v", "p", "h"]
colors = ["g", "b", "y", "m", "r", "c", "orange"]

pylab.loglog(all_gw_fap, all_gw_eff, color='k', linestyle="--", linewidth=2, marker ="x", markersize=0.0, label="gw data only")
for i in range(len(elabels)):
  pylab.loglog(faps_effs[i][1], faps_effs[i][2], color=colors[i], linestyle="-", linewidth=2, marker=markers[i], markersize=0.0, label=("gw-em "+ label_dic[faps_effs[i][0]]))


if opts.roc_glob_10pxls:
  pylab.hold(True)
  for i in range(len(elabels_10pxls)):
    pylab.loglog(FAP0*faps_effs_10pxls[i][1], N_factor*faps_effs_10pxls[i][2], color=colors[i], linestyle=":", linewidth=2, marker=markers[i], markersize=0.0)



#pylab.axvline(1.0 - scipy.special.erf(1.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(2.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(3.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(4.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(5.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(6.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(7.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(8.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(9.0/2.0**0.5), color="gray", linestyle="--")
#pylab.axvline(1.0 - scipy.special.erf(10.0/2.0**0.5), color="gray", linestyle="--")

sigmas = []
xticks_labels = []
for i in range(8,0,-1):
  sigmas.append(1.0 - scipy.special.erf(float(i)/2.0**0.5))
  xticks_labels.append(str(i)+r"$\sigma$")
pylab.xticks(sigmas, xticks_labels)
pylab.xlim(xmin=(1.0 - scipy.special.erf(3.0/2.0**0.5)))
pylab.ylim(ymin=2*10.0**-1)
pylab.grid()

pylab.xlabel(r"False Alarm Probability")
pylab.ylabel(r"Efficiency")
pylab.title("ROC curves for CWB and CWB+SWIFT searches")
#pylab.legend(loc=2)
pylab.legend(loc=4)

pylab.savefig("cwb_swift_roc_zoom.png")
pylab.savefig("cwb_swift_roc_zoom.pdf")
pylab.savefig("cwb_swift_roc_zoom.eps")

pylab.close()






